@@ -152,13 +152,9 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(
         id: str,
         *,
         domain_name: str,
-        dynamo_event_source_props: typing.Optional[
-            aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps
-        ] = None,
+        dynamo_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps] = None,
         dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
-        es_domain_props: typing.Optional[
-            aws_cdk.aws_elasticsearch.CfnDomainProps
-        ] = None,
+        es_domain_props: typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
@@ -191,9 +187,7 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(
             lambda_function_props=lambda_function_props,
         )
 
-        jsii.create(
-            DynamoDBStreamToLambdaToElasticSearchAndKibana, self, [scope, id, props]
-        )
+        jsii.create(DynamoDBStreamToLambdaToElasticSearchAndKibana, self, [scope, id, props])
 
     @builtins.property
     @jsii.member(jsii_name="cloudwatchAlarms")
@@ -254,13 +248,9 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps:
         self,
         *,
         domain_name: str,
-        dynamo_event_source_props: typing.Optional[
-            aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps
-        ] = None,
+        dynamo_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps] = None,
         dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
-        es_domain_props: typing.Optional[
-            aws_cdk.aws_elasticsearch.CfnDomainProps
-        ] = None,
+        es_domain_props: typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
         existing_table_obj: typing.Optional[aws_cdk.aws_dynamodb.Table] = None,
         lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
@@ -278,19 +268,13 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps:
         :summary:: The properties for the DynamoDBStreamToLambdaToElastciSearchAndKibana Construct
         """
         if isinstance(dynamo_event_source_props, dict):
-            dynamo_event_source_props = aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps(
-                **dynamo_event_source_props
-            )
+            dynamo_event_source_props = aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps(**dynamo_event_source_props)
         if isinstance(dynamo_table_props, dict):
             dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
         if isinstance(es_domain_props, dict):
-            es_domain_props = aws_cdk.aws_elasticsearch.CfnDomainProps(
-                **es_domain_props
-            )
+            es_domain_props = aws_cdk.aws_elasticsearch.CfnDomainProps(**es_domain_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(
-                **lambda_function_props
-            )
+            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
         self._values = {
             "domain_name": domain_name,
         }
